@@ -1,8 +1,7 @@
-from nautilus_librarian.domain.validate_filepaths import validate_filepath
-from nautilus_librarian.mods.dvc.domain.utils import (
-    extract_list_of_new_or_renamed_files_from_dvc_diff_output,
-    get_new_filepath_if_is_a_renaming_dict,
+from nautilus_librarian.domain.dvc_diff_media_parser import (
+    extract_list_of_new_and_renamed_files_from_dvc_diff_output,
 )
+from nautilus_librarian.domain.validate_filepaths import validate_filepath
 from nautilus_librarian.typer.commands.workflows.actions.action_result import (
     ActionResult,
     ErrorMessage,
@@ -20,18 +19,17 @@ def validate_filepaths_action(dvc_diff):
             ResultCode.EXIT, [Message("No media library file changes found")]
         )
 
-    filepaths = extract_list_of_new_or_renamed_files_from_dvc_diff_output(dvc_diff)
+    filepaths = extract_list_of_new_and_renamed_files_from_dvc_diff_output(dvc_diff)
 
     messages = []
 
     for filepath in filepaths:
         try:
-            extracted_filepath = get_new_filepath_if_is_a_renaming_dict(filepath)
-            validate_filepath(extracted_filepath)
-            messages.append(Message(f"{extracted_filepath} ✓"))
+            validate_filepath(str(filepath.get_value()))
+            messages.append(Message(f"{filepath} ✓"))
         except ValueError as error:
             return ActionResult(
-                ResultCode.ABORT, [ErrorMessage(f"{extracted_filepath} ✗ {error}")]
+                ResultCode.ABORT, [ErrorMessage(f"{filepath} ✗ {error}")]
             )
 
     return ActionResult(ResultCode.CONTINUE, messages)
