@@ -1,6 +1,5 @@
-from nautilus_librarian.mods.dvc.domain.utils import (
+from nautilus_librarian.domain.dvc_diff_media_parser import (
     extract_added_and_modified_files_from_dvc_diff,
-    get_new_filepath_if_is_a_renaming_dict,
 )
 from nautilus_librarian.mods.libvips.domain.validate_image_dimensions import (
     validate_image_dimensions,
@@ -13,7 +12,9 @@ from nautilus_librarian.typer.commands.workflows.actions.action_result import (
 )
 
 
-def validate_images_dimensions(dvc_diff, min_image_size, max_image_size):
+def validate_images_dimensions_action(
+    dvc_diff, git_repo_dir, min_image_size, max_image_size
+):
     """
     It validates all the media sizes in the dvc diff.
     """
@@ -22,29 +23,23 @@ def validate_images_dimensions(dvc_diff, min_image_size, max_image_size):
             ResultCode.CONTINUE, [Message("No Gold image changes found")]
         )
 
-    filenames = extract_added_and_modified_files_from_dvc_diff(
-        dvc_diff, only_basename=False
-    )
+    filenames = extract_added_and_modified_files_from_dvc_diff(dvc_diff)
 
     messages = []
 
     for filename in filenames:
+        absolute_filepath = f"{git_repo_dir}/{filename}"
         try:
-            extracted_filename = get_new_filepath_if_is_a_renaming_dict(filename)
             (width, height) = validate_image_dimensions(
-                extracted_filename, min_image_size, max_image_size
+                absolute_filepath, min_image_size, max_image_size
             )
             messages.append(
-                Message(f"✓ Dimensions of {extracted_filename} are {width} x {height}")
+                Message(f"✓ Dimensions of {str(filename)} are {width} x {height}")
             )
         except ValueError as error:
             return ActionResult(
                 ResultCode.ABORT,
-                [
-                    ErrorMessage(
-                        f"✗ Dimensions of {extracted_filename} are wrong: {error}"
-                    )
-                ],
+                [ErrorMessage(f"✗ Dimensions of {str(filename)} are wrong: {error}")],
             )
 
     return ActionResult(ResultCode.CONTINUE, messages)
