@@ -29,17 +29,23 @@ def git_user(gpg_signing_key_info):
 
 @pytest.fixture(scope="session")
 def sample_gold_image_relative_path():
-    base_image_path = "images/000001-32.600.2.tif"
-    return base_image_path
+    return "images/000001-32.600.2.tif"
 
 
 @pytest.fixture(scope="session")
-def sample_base_image_absolute_path(workflows_fixtures_dir):
-    base_image_path = f"{workflows_fixtures_dir}/images/000001-52.600.2.tif"
-    return base_image_path
+def sample_base_image_relative_path():
+    return "images/000001-52.600.2.tif"
 
 
 @pytest.fixture(scope="session")
-def sample_gold_image_absolute_path(workflows_fixtures_dir):
-    gold_image_path = f"{workflows_fixtures_dir}/images/000001-32.600.2.tif"
-    return gold_image_path
+def sample_gold_image_absolute_path(
+    workflows_fixtures_dir, sample_gold_image_relative_path
+):
+    return f"{workflows_fixtures_dir}/{sample_gold_image_relative_path}"
+
+
+@pytest.fixture(scope="session")
+def sample_base_image_absolute_path(
+    workflows_fixtures_dir, sample_base_image_relative_path
+):
+    return f"{workflows_fixtures_dir}/{sample_base_image_relative_path}"
